<?php
/**
 * Feed Maintenance Page
 *
 * List feeds and provide links for maintenance actions
 */

include '../start.php';

$db = Data::getConnection();
Security::verifyUser($db);

$feedQuery = $db->prepare('SELECT * FROM feed WHERE user_id = :user ORDER BY lower(title)');
$feedQuery->bindValue(':user', $_SESSION[Key::USER_ID]);
if (!($feedResult = $feedQuery->execute())) {
    add_error(Data::error($db)['error']);
}

page_head('Your Feeds'); ?>
<h1>Your Feeds</h1>
<article>
    <p class=action_buttons><?=hx_get('/feed/?id=new', 'Add Feed')?></p><?php
    if ($feedResult) {
        while ($feed = $feedResult->fetchArray(SQLITE3_ASSOC)) {
            $feedId = $feed['id'];
            $countQuery = $db->prepare(<<<'SQL'
                SELECT (SELECT COUNT(*) FROM item WHERE feed_id = :feed)                       AS total,
                       (SELECT COUNT(*) FROM item WHERE feed_id = :feed AND is_read = 0)       AS unread,
                       (SELECT COUNT(*) FROM item WHERE feed_id = :feed AND is_bookmarked = 1) AS marked
                SQL);
            $countQuery->bindValue(':feed', $feed['id']);
            $countResult = $countQuery->execute();
            $counts = $countResult
                ? $countResult->fetchArray(SQLITE3_ASSOC) : ['total' => 0, 'unread' => 0, 'marked' => 0]; ?>
            <p><strong><?=htmlentities($feed['title'])?></strong><br>
                <span class=meta><em>Last Updated <?=date_time($feed['updated_on'])?> &bull;
                    As of <?=date_time($feed['checked_on'])?></em><br>
                <?=hx_get("/feed/?id=$feedId", 'Edit')?> &bull; Read
                <?=$counts['unread'] > 0 ? hx_get("/feed/items?id=$feedId&unread", 'Unread') : 'Unread'?>
                (<?=$counts['unread']?>) |
                <?=$counts['total'] > 0 ? hx_get("/feed/items?id=$feedId", 'All') : 'All'?> (<?=$counts['total']?>) |
                <?=$counts['marked'] > 0 ? hx_get("/feed/items?id=$feedId&bookmarked", 'Bookmarked') : 'Bookmarked'?>
                (<?=$counts['marked']?>) &bull;
                <a href=/feed/?id=<?=$feedId?> hx-delete=/feed/?id=<?=$feedId?>
                   hx-confirm="Are you sure you want to delete &ldquo;<?=htmlentities($feed['title'], ENT_QUOTES)?>&rdquo;? This will remove the feed and all its items, including unread and bookmarked.">Delete</a>
                </span><?php
        }
    } ?>
</article><?php
page_foot();
$db->close();
